Parsion - A simple LR(0) parser
===============================

Parsion is intended to be a simple drop-in parser generator, lexer and parser for grammars in python

It's main intention is to make it possible to load and create a grammar for simple expression parsers without using code generation.

Example
-------

See [example.py](example.py)
